@@ -1,5 +1,6 @@
 import Paper from '@material-ui/core/Paper';
 import Popper, { PopperProps } from '@material-ui/core/Popper';
+import makeStyles from '@material-ui/styles/makeStyles';
 import clsx from 'clsx';
 import { forwardRef, useState } from 'react';
 
@@ -13,6 +14,12 @@ interface PopperEvent {
   flipped: boolean;
 }
 
+const useStyles = makeStyles({
+  flipped: {
+    transform: 'rotate(180deg)',
+  },
+});
+
 /**
  * Component for rendering popups. This includes an arrow that centers around
  * the anchor element.
@@ -21,6 +28,7 @@ export const Popup = forwardRef<HTMLDivElement, Props>(
   ({ children, paperClassName, ...props }, ref) => {
     // State to flip the popup arrow if the popper state is flipped.
     const [flipped, setFlipped] = useState(false);
+    const classes = useStyles();
 
     return (
       <Popper
@@ -47,7 +55,9 @@ export const Popup = forwardRef<HTMLDivElement, Props>(
             {children}
           </Paper>
 
-          {!flipped && <PopupArrow className="tw-z-10 tw-rotate-180" />}
+          {!flipped && (
+            <PopupArrow className={clsx('tw-z-10', classes.flipped)} />
+          )}
         </div>
       </Popper>
     );
